@@ -9,13 +9,23 @@ use File::Spec   0.80 ();
 use File::Temp   0.20 ();
 use File::Path   2.04 ();
 use File::Basename  0 ();
-use Params::Util 0.33 qw{ _STRING _CLASS _HASHLIKE _CODELIKE };
+use Params::Util 0.33 ();
 use DBI         1.607 ();
 use DBD::SQLite  1.25 ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.25';
+	$VERSION = '1.27';
+}
+
+# Support for the 'prune' option
+my @PRUNE = ();
+END {
+	foreach ( @PRUNE ) {
+		next unless -e $_;
+		require File::Remove;
+		File::Remove::remove($_);
+	}
 }
 
 
@@ -30,14 +40,14 @@ sub import {
 
 	# Check for debug mode
 	my $DEBUG = 0;
-	if ( defined _STRING($_[-1]) and $_[-1] eq '-DEBUG' ) {
+	if ( defined Params::Util::_STRING($_[-1]) and $_[-1] eq '-DEBUG' ) {
 		$DEBUG = 1;
 		pop @_;
 	}
 
 	# Check params and apply defaults
 	my %params;
-	if ( defined _STRING($_[1]) ) {
+	if ( defined Params::Util::_STRING($_[1]) ) {
 		# Support the short form "use ORLite 'db.sqlite'"
 		%params = (
 			file     => $_[1],
@@ -45,7 +55,7 @@ sub import {
 			package  => undef, # Automatic
 			tables   => 1,
 		);
-	} elsif ( _HASHLIKE($_[1]) ) {
+	} elsif ( Params::Util::_HASHLIKE($_[1]) ) {
 		%params = %{ $_[1] };
 	} else {
 		Carp::croak("Missing, empty or invalid params HASH");
@@ -54,7 +64,7 @@ sub import {
 		$params{create} = 0;
 	}
 	unless (
-		defined _STRING($params{file})
+		defined Params::Util::_STRING($params{file})
 		and (
 			$params{create}
 			or
@@ -72,7 +82,7 @@ sub import {
 	unless ( defined $params{package} ) {
 		$params{package} = scalar caller;
 	}
-	unless ( _CLASS($params{package}) ) {
+	unless ( Params::Util::_CLASS($params{package}) ) {
 		Carp::croak("Missing or invalid package class");
 	}
 
@@ -83,8 +93,10 @@ sub import {
 		# Create the parent directory
 		my $dir = File::Basename::dirname($file);
 		unless ( -d $dir ) {
-			File::Path::mkpath( $dir, { verbose => 0 } );
+			my @dirs = File::Path::mkpath( $dir, { verbose => 0 } );
+			push @PRUNE, @dirs if $params{prune};
 		}
+		push @PRUNE, $file if $params{prune};
 	}
 	my $pkg      = $params{package};
 	my $readonly = $params{readonly};
@@ -92,7 +104,7 @@ sub import {
 	my $dbh      = DBI->connect($dsn);
 
 	# Schema creation support
-	if ( $created and _CODELIKE($params{create}) ) {
+	if ( $created and Params::Util::_CODELIKE($params{create}) ) {
 		$params{create}->( $dbh );
 	}
 
@@ -435,7 +447,7 @@ sub dval {
 	} grep {
 		/^(?:package|sub)\b/
 	} split /\n/, $_[0];
-	print STDERR @trace, "\nCode saved as $filename\n\n";
+	# print STDERR @trace, "\nCode saved as $filename\n\n";
 
 	return 1;
 }
@@ -453,14 +465,34 @@ ORLite - Extremely light weight SQLite-specific ORM
 =head1 SYNOPSIS
 
   package Foo;
-
+  
+  # Simplest possible usage
+  
   use strict;
   use ORLite 'data/sqlite.db';
-
+  
   my @awesome = Foo::Person->select(
      'where first_name = ?',
      'Adam',
   );
+  
+  package Bar;
+  
+  # All available options enabled
+  # Some options shown are mutually exclusive, this would not actually run
+  
+  use ORLite {
+      package      => 'My::ORM',
+      file         => 'data/sqlite.db',
+      user_version => 12,
+      tables       => [ 'table1', 'table2' ],
+      readonly     => 1,
+      prune        => 1,
+      create       => sub {
+          my $dbh = shift;
+          $dbh->do('CREATE TABLE foo ( bar TEXT NOT NULL )');
+      },
+  );
 
 =head1 DESCRIPTION
 
